Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/swiift/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/api.py | _ProgressBarProtocol | 0 | 0 | 2 | 0 | 0 | 100%
src/swiift/api/api.py | _VerboseProgressBarProtocol | 0 | 0 | 1 | 0 | 0 | 100%
src/swiift/api/api.py | Experiment | 82 | 82 | 16 | 30 | 0 | 0%
src/swiift/api/api.py | (no class) | 82 | 82 | 29 | 8 | 0 | 0%
src/swiift/api/spectra.py | _ParametrisedSpectrum | 3 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/spectra.py | _UnimodalSpectrum | 2 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/spectra.py | _PMFamily | 3 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/spectra.py | PiersonMoskowitz | 7 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/spectra.py | Bretschneider | 3 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/spectra.py | JONSWAP | 8 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/spectra.py | (no class) | 61 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/utils.py | (no class) | 12 | 12 | 2 | 0 | 0 | 0%
src/swiift/lib/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/_ph_utils.py | (no class) | 5 | 2 | 0 | 0 | 0 | 60%
src/swiift/lib/att.py | AttenuationParameterisation | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/att.py | AttenuationSpecification | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/att.py | (no class) | 21 | 4 | 0 | 0 | 0 | 81%
src/swiift/lib/constants.py | (no class) | 5 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/dr.py | FreeSurfaceSolver | 23 | 23 | 0 | 10 | 0 | 0%
src/swiift/lib/dr.py | ElasticMassLoadingSolver | 36 | 36 | 0 | 14 | 0 | 0%
src/swiift/lib/dr.py | (no class) | 32 | 0 | 2 | 0 | 0 | 100%
src/swiift/lib/graphics.py | (no class) | 103 | 87 | 2 | 24 | 0 | 13%
src/swiift/lib/numerical.py | (no class) | 142 | 109 | 85 | 42 | 0 | 18%
src/swiift/lib/phase_shift.py | _ScatteringHandler | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/phase_shift.py | ContinuousScatteringHandler | 1 | 1 | 0 | 0 | 0 | 0%
src/swiift/lib/phase_shift.py | _RandomScatteringHandler | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/phase_shift.py | UniformScatteringHandler | 3 | 3 | 0 | 0 | 0 | 0%
src/swiift/lib/phase_shift.py | PerturbationScatteringHandler | 6 | 6 | 0 | 0 | 0 | 0%
src/swiift/lib/phase_shift.py | (no class) | 33 | 1 | 0 | 0 | 0 | 97%
src/swiift/lib/physics.py | FluidSurfaceHandler | 3 | 3 | 0 | 0 | 0 | 0%
src/swiift/lib/physics.py | DisplacementHandler | 12 | 12 | 0 | 2 | 0 | 0%
src/swiift/lib/physics.py | CurvatureHandler | 15 | 15 | 0 | 2 | 0 | 0%
src/swiift/lib/physics.py | StrainHandler | 2 | 2 | 0 | 0 | 0 | 0%
src/swiift/lib/physics.py | EnergyHandler | 95 | 95 | 0 | 2 | 0 | 0%
src/swiift/lib/physics.py | (no class) | 106 | 24 | 2 | 4 | 0 | 76%
src/swiift/model/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/model/frac_handlers.py | _StrainDiag | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/model/frac_handlers.py | _FractureDiag | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/model/frac_handlers.py | _FractureHandler | 12 | 12 | 0 | 2 | 0 | 0%
src/swiift/model/frac_handlers.py | BinaryFracture | 31 | 31 | 0 | 10 | 0 | 0%
src/swiift/model/frac_handlers.py | _StrainFracture | 13 | 13 | 0 | 0 | 0 | 0%
src/swiift/model/frac_handlers.py | BinaryStrainFracture | 5 | 5 | 0 | 2 | 0 | 0%
src/swiift/model/frac_handlers.py | MultipleStrainFracture | 5 | 5 | 0 | 2 | 0 | 0%
src/swiift/model/frac_handlers.py | (no class) | 52 | 3 | 0 | 0 | 0 | 94%
src/swiift/model/model.py | Ocean | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/model/model.py | _Subdomain | 1 | 1 | 0 | 0 | 0 | 0%
src/swiift/model/model.py | Ice | 3 | 3 | 0 | 0 | 0 | 0%
src/swiift/model/model.py | FloatingIce | 8 | 8 | 0 | 0 | 0 | 0%
src/swiift/model/model.py | WavesUnderElasticPlate | 5 | 5 | 0 | 0 | 0 | 0%
src/swiift/model/model.py | WavesUnderIce | 7 | 7 | 0 | 2 | 0 | 0%
src/swiift/model/model.py | FreeSurfaceWaves | 4 | 4 | 0 | 0 | 0 | 0%
src/swiift/model/model.py | Floe | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/model/model.py | WavesUnderFloe | 9 | 9 | 2 | 2 | 0 | 0%
src/swiift/model/model.py | DiscreteSpectrum | 20 | 20 | 0 | 8 | 0 | 0%
src/swiift/model/model.py | Domain | 78 | 78 | 0 | 46 | 0 | 0%
src/swiift/model/model.py | (no class) | 147 | 0 | 8 | 0 | 0 | 100%
tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/helpers.py | (no class) | 18 | 18 | 0 | 2 | 0 | 0%
tests/model_strategies.py | TestingConstants | 0 | 0 | 0 | 0 | 0 | 100%
tests/model_strategies.py | (no class) | 27 | 27 | 0 | 0 | 0 | 0%
tests/physical_strategies.py | (no class) | 22 | 7 | 0 | 0 | 0 | 68%
tests/test_attenuation.py | TestNoAttenuation | 5 | 5 | 0 | 0 | 0 | 0%
tests/test_attenuation.py | TestParam01 | 6 | 6 | 0 | 0 | 0 | 0%
tests/test_attenuation.py | TestYu2022 | 10 | 10 | 0 | 0 | 0 | 0%
tests/test_attenuation.py | TestGeneric | 20 | 20 | 0 | 0 | 0 | 0%
tests/test_attenuation.py | (no class) | 42 | 42 | 0 | 0 | 0 | 0%
tests/test_diagnosis.py | (no class) | 36 | 36 | 28 | 0 | 0 | 0%
tests/test_disp_relations.py | (no class) | 45 | 45 | 0 | 0 | 0 | 0%
tests/test_domain.py | (no class) | 92 | 92 | 2 | 10 | 0 | 0%
tests/test_experiment.py | DummyPbar | 5 | 5 | 0 | 0 | 0 | 0%
tests/test_experiment.py | (no class) | 355 | 355 | 0 | 36 | 0 | 0%
tests/test_fracture.py | (no class) | 121 | 121 | 2 | 18 | 0 | 0%
tests/test_graphics.py | (no class) | 11 | 11 | 0 | 2 | 0 | 0%
tests/test_model_objects.py | TestSubdomain | 2 | 2 | 0 | 0 | 0 | 0%
tests/test_model_objects.py | (no class) | 7 | 7 | 0 | 0 | 0 | 0%
tests/test_numerical.py | (no class) | 29 | 29 | 0 | 12 | 0 | 0%
tests/test_param_spectra.py | TestPiersonMoskowitz | 4 | 0 | 0 | 0 | 0 | 100%
tests/test_param_spectra.py | TestBretschneider | 3 | 0 | 0 | 0 | 0 | 100%
tests/test_param_spectra.py | (no class) | 43 | 0 | 0 | 4 | 0 | 100%
tests/test_physical_handlers.py | (no class) | 62 | 62 | 0 | 4 | 0 | 0%
tests/test_physics.py | _TestPhysics | 57 | 57 | 0 | 12 | 0 | 0%
tests/test_physics.py | TestPhysicsMono | 5 | 5 | 0 | 0 | 0 | 0%
tests/test_physics.py | TestPhysicsPoly | 20 | 20 | 0 | 10 | 0 | 0%
tests/test_physics.py | (no class) | 67 | 67 | 2 | 0 | 0 | 0%
tests/test_pscattering.py | (no class) | 35 | 35 | 0 | 4 | 0 | 0%
tests/test_spectrum.py | (no class) | 73 | 73 | 0 | 22 | 0 | 0%
tests/utils.py | FloatsKWA | 0 | 0 | 0 | 0 | 0 | 100%
tests/utils.py | (no class) | 10 | 0 | 0 | 0 | 0 | 100%
Total |  | 2538 | 1960 | 185 | 348 | 0 | 20%

No items found using the specified filter.